class DNSConfig {
  final bool enable;
  final String listen;
  final bool ipv6;
  final String enhancedMode;
  final List<String> defaultNameserver;
  final List<String> nameserver;
  final List<String> proxyServerNameserver;
  final Map<String, List<String>> nameserverPolicy;

  DNSConfig({
    required this.enable,
    required this.listen,
    required this.ipv6,
    required this.enhancedMode,
    required this.defaultNameserver,
    required this.nameserver,
    required this.proxyServerNameserver,
    required this.nameserverPolicy,
  });

// 同样可以添加解析方法
  factory DNSConfig.fromMap(Map<String, dynamic> map) {
    return DNSConfig(
      enable: map['enable'],
      listen: map['listen'],
      ipv6: map['ipv6'],
      enhancedMode: map['enhanced-mode'],
      defaultNameserver: List<String>.from(map['default-nameserver']),
      nameserver: List<String>.from(map['nameserver']),
      proxyServerNameserver: List<String>.from(map['proxy-server-nameserver']),
      nameserverPolicy: Map.from(map['nameserver-policy']).map((key, value) => MapEntry(key, List<String>.from(value))),
    );
  }

  Map<String, dynamic> toJson() {
    return {
      'enable': enable,
      'listen': listen,
      'ipv6': ipv6,
      'enhanced-mode': enhancedMode,
      'default-nameserver': defaultNameserver,
      'nameserver': nameserver,
      'proxy-server-nameserver': proxyServerNameserver,
      'nameserver-policy': nameserverPolicy.map((key, value) => MapEntry(key, value)),
    };
  }

  String toYaml() {
    return '''
dns:
  enable: $enable
  listen: '$listen'
  ipv6: $ipv6
  enhanced-mode: $enhancedMode
  default-nameserver:
    ${defaultNameserver.map((ns) => '    - $ns').join('\n')}
  nameserver:
    ${nameserver.map((ns) => '    - $ns').join('\n')}
  proxy-server-nameserver:
    ${proxyServerNameserver.map((ns) => '    - $ns').join('\n')}
  nameserver-policy:
    ${_mapToYaml(nameserverPolicy)}
''';
  }

  String _mapToYaml(Map<String, List<String>> map) {
    var yamlString = '';
    map.forEach((key, value) {
      yamlString += '    "$key":\n      ${value.map((v) => '- $v').join('\n      ')}\n';
    });
    return yamlString;
  }

}
